lemma_iset_union_again1

Function lemma_iset_union_again1 

pub broadcast proof fn lemma_iset_union_again1<A>(a: ISet<A>, b: ISet<A>)
ensures
#[trigger] a.union(b).union(b) =~= a.union(b),

Taking the union of sets a and b and then taking the union of the result with b is the same as taking the union of a and b once.